@@ -136,7 +136,7 @@ func verifyOperatorUp(t *testing.T) *samplesapi.Config {
 	return cfg
 }
 
-func verifyX86(t *testing.T) bool {
+func verifySupportedArch(t *testing.T) bool {
 	err := wait.PollImmediate(1*time.Second, 1*time.Minute, func() (bool, error) {
 		cfg := verifyOperatorUp(t)
 		if len(cfg.Status.Architectures) == 0 {
@@ -148,7 +148,10 @@ func verifyX86(t *testing.T) bool {
 	if err != nil {
 		t.Fatalf("architecture field was not set after 1 minute: %#v", cfg)
 	}
-	if cfg.Status.Architectures[0] != samplesapi.X86Architecture && cfg.Status.Architectures[0] != samplesapi.AMDArchitecture {
+	if cfg.Status.Architectures[0] != samplesapi.X86Architecture &&
+		cfg.Status.Architectures[0] != samplesapi.AMDArchitecture &&
+		cfg.Status.Architectures[0] != samplesapi.S390Architecture &&
+		cfg.Status.Architectures[0] != samplesapi.PPCArchitecture {
 		return false
 	}
 	return true
@@ -533,7 +536,7 @@ func verifyTemplatesGone(t *testing.T) {
 }
 
 func validateContent(t *testing.T, timeToCompare *kapis.Time) {
-	if !verifyX86(t) {
+	if !verifySupportedArch(t) {
 		return
 	}
 	if verifyIPv6(t) {
@@ -643,7 +646,7 @@ func verifySkippedTemplateManagedLabel(t *testing.T, value string) {
 }
 
 func verifyDeletedImageStreamNotRecreated(t *testing.T) {
-	if !verifyX86(t) {
+	if !verifySupportedArch(t) {
 		return
 	}
 	if verifyIPv6(t) {
@@ -707,7 +710,7 @@ func verifyDeletedTemplatesRecreated(t *testing.T) {
 }
 
 func verifyDeletedTemplatesNotRecreated(t *testing.T) {
-	if !verifyX86(t) {
+	if !verifySupportedArch(t) {
 		return
 	}
 	if verifyIPv6(t) {
@@ -988,7 +991,7 @@ func TestSpecManagementStateField(t *testing.T) {
 }
 
 func TestSkippedProcessing(t *testing.T) {
-	if !verifyX86(t) {
+	if !verifySupportedArch(t) {
 		return
 	}
 	if verifyIPv6(t) {
@@ -1075,7 +1078,7 @@ func TestSkippedProcessing(t *testing.T) {
 }
 
 func TestRecreateDeletedManagedSample(t *testing.T) {
-	if !verifyX86(t) {
+	if !verifySupportedArch(t) {
 		return
 	}
 	if verifyIPv6(t) {
